#! /usr/local/bin/perl
BEGIN { $| = 1; print "1..1\n"; }
use DAL;

my $set = "abc.ds";
my $nx = 10;
my $ny = 5;
my $imdim = [$nx,$ny];

my $ds = DAL::dataset->new(name => $set,
			   mode => $DAL::CREATE);

my $icount = 0;

foreach($DAL::INT8, $DAL::INT16, $DAL::INT32, $DAL::REAL32, $DAL::REAL64) {
    my $imtype = $_;
    my $im = $ds->addArray(name => "array_$icount",
			   datatype => $imtype,
			   dimensions => $imdim);
    $icount++;
    
    foreach($DAL::BOOL, $DAL::INT8, $DAL::INT16, $DAL::REAL32, $DAL::REAL64, $DAL::STRING) {
	my $attype = $_;
	$im->addAttribute(name => "F_$_",
			  datatype => $attype,
			  value => 1,
			  label => "Comment",
			  units => "Units"
			  );
    }
    my $v = $im->data();
    for(my $i = 0; $i < $nx*$ny; $i++){
	$v->set($i,$i);
    }
}

$ds->release();

$ds = DAL::dataset->new(name => $set,
			mode => $DAL::MODIFY);
my $ifail = 0;

for(my $i=0; $i<$icount; $i++){
    my $im;
    if(not $ds->hasBlock(name => "array_$i")){
	warn("Block array_$i not found.");
	$ifail++;
	next;
    } else {
	$im = $ds->array(name => "array_$i");
    }
    
    foreach($DAL::BOOL, $DAL::INT8, $DAL::INT16, $DAL::REAL32, $DAL::REAL64, $DAL::STRING) {
	my $attype = $_;
	if(not $im->hasAttribute(name => "F_$_")){
	    warn("In $im->name() the attribute F_$_ could not be found.");
	    $ifail++;
	}
    }
    
    print $im->name(),"\n";
    my $v = $im->data();
    for(my $i = 0; $i < $nx*$ny; $i++){
	my $val = $v->value($i);
	if($i != $val){
	    warn("Data failure $i: $val\n" );
	    $ifail++;
	}
    }

    $im->release();
    
    $ds->deleteBlock(name => "array_$i");
}

$ds->release();

$ds = DAL::dataset->new(name => $set,
			mode => $DAL::MODIFY);
for(my $i=0; $i<$icount; $i++) {
    my $im;
    if($ds->hasBlock(name => "array_$i")){
	warn("Block array_$i found?");
	$ifail++;
    }
}

$ds->release();

exit($ifail) if $ifail;

unlink $set;

print "ok 1\n";

